/**
 * FilledRect.java
 */
package UTEStatsViewer;
import java.awt.*;

/** A component that draws a filled rectangle. */
public class FilledRect extends Component {
   // the preferred and minimum size of the component
   private Dimension desiredSize;


   /**
    * Create a filled rectangle.
    * @param width the width of the rectangle in pixels
    * @param height the height of the rectangle in pixels
    * @param color the color of the rectangle
    */
   public FilledRect(int width, int height, Color color) {
      setForeground(color);
      desiredSize = new Dimension(width, height);
   }


   /**
    * Create a filled rectangle.
    * @param width the width of the rectangle in pixels
    * @param height the height of the rectangle in pixels
    */
   public FilledRect(int width, int height) {
      desiredSize = new Dimension(width, height);
   }


   /** Override getPreferredSize to return the desired size. */
   public Dimension getPreferredSize() {
      return desiredSize;
   }


   /** Override getMinimumSize to return the desired size. */
   public Dimension getMinimumSize() {
      return desiredSize;
   }


   /** Override paint to draw the rectangle. */
   public void paint(Graphics g) {
      Dimension actualSize = getSize();

      // draw rectangle in foreground color
      g.setColor(getForeground());
      g.fillRect(0, 0, actualSize.width, actualSize.height);

      // draw an inside edge in a color that constrasts with the background
      g.setColor(new Color(0x00ffffff ^ getBackground().getRGB()));
      g.drawRect(0, 0, actualSize.width - 1, actualSize.height - 1);
   }
}
