/* HorzAxisLabel.java */
package UTEStatsViewer;
import java.awt.*;
import com_ibm_us_bolmar.GraphicPlotter.*;

/**
 * A horizontal axis label (also usable as a component).
 */
public class HorzAxisLabel extends AxisLabel {
   /** Create a horizontal axis label with the given name. */
   public HorzAxisLabel(String name) {
      setName(name);
   }


   /** Return the name as the short name to be used in prompts. */
   public String getShortName() {
      return getName();
   }


   /* Return the minimum size of the Component. */
   public Dimension getMinimumSize() {
      return getPreferredSize();
   }


   /* Return the preferred size of the Component. */
   public Dimension getPreferredSize() {
      FontMetrics fontMetrics = getFontMetrics(getFont());
      int width = fontMetrics.stringWidth(getName());
      int height = fontMetrics.getMaxAscent() +
            fontMetrics.getMaxDescent() + fontMetrics.getLeading();
      return new Dimension(width, height);
   }


   /* Paint the Component centered in the available space. */
   public void paint(Graphics g) {
      String name = getName();
      Dimension mySize = getSize();
      Font font = getFont();
      FontMetrics fontMetrics = getFontMetrics(font);
      int x = (mySize.width - fontMetrics.stringWidth(name))/2;
      int y = (mySize.height + fontMetrics.getAscent() -
            fontMetrics.getDescent()) / 2;

      g.setFont(font);
      g.drawString(name, x, y);
   }
}
